@@ -26,6 +26,8 @@ import asyncio
 import logging
 import signal
 from typing import Any, Coroutine, Dict, List, Union
+from asyncache import cached
+from cachetools import TTLCache
 
 import socketio
 
@@ -204,6 +206,7 @@ class Client:
             except asyncio.TimeoutError:
                 _log.info("Connection timed out.")
                 await self.close()
+                await asyncio.sleep(5)  # Sleep 5 seconds to handle connection closing
 
     async def close(self) -> None:
         """*coroutine*
@@ -217,6 +220,7 @@ class Client:
             await self.ws.eio.http.close()
         await self.http.close()
 
+    @cached(cache=TTLCache(maxsize=128, ttl=300))
     async def get_items(
         self,
         *,
@@ -253,9 +257,9 @@ class Client:
         data = await self.http.get_items(params=params)
         return [Item(data=item) for item in data]
 
+    @cached(cache=TTLCache(maxsize=16, ttl=3600))
     async def get_sales_history(
         self,
-        *market_hash_names: str,
         app_id: int = 730,
         currency: Currency = Currency.eur,
     ) -> List[ItemWithSales]:  # sourcery skip: default-mutable-arg
@@ -275,16 +279,14 @@ class Client:
         -------
         :class:`list` of :class:`ItemWithSales`
         """
-        if not market_hash_names:
-            raise ParamRequired("At least one market_hash_name is required.")
         params = {
-            "market_hash_name": ",".join(market_hash_names),
             "app_id": app_id,
             "currency": currency.value,
         }
         data = await self.http.get_sales_history(params=params)
         return [ItemWithSales(data=sale) for sale in data]
 
+    @cached(cache=TTLCache(maxsize=16, ttl=3600))
     async def get_sales_out_of_stock(
         self, *, app_id: int = 730, currency: Currency = Currency.eur
     ) -> List[ItemOutOfStock]:
